@@ -3,6 +3,7 @@
 from metapi.configer import metaconfig
 from metapi.configer import parse_yaml
 from metapi.configer import update_config
+from metapi.configer import custom_help_formatter
 
 from metapi.tooler import parse
 from metapi.tooler import merge
@@ -18,19 +19,29 @@ from metapi.sampler import get_sample_id_
 
 from metapi.qcer import change
 from metapi.qcer import compute_host_rate
+from metapi.qcer import qc_bar_plot
 
 from metapi.assembler import assembler_init
 from metapi.assembler import parse_assembly
+from metapi.assembler import parse_spades_params
 
 from metapi.aligner import flagstats_summary
 
-from metapi.checkmer import checkm_report
+from metapi.binner import get_binning_info
+from metapi.binner import generate_bins
+
+from metapi.checkmer import checkm_reporter
 
 from metapi.classifier import demultiplex
 
 from metapi.profiler import profiler_init
 from metapi.profiler import get_all_abun_df
+from metapi.profiler import get_abun_df_bgi_soap
+from metapi.profiler import get_abun_df_bowtie2
+from metapi.profiler import get_abun_df_jgi
 from metapi.profiler import get_profile
+from metapi.profiler import metaphlan_init
+from metapi.profiler import merge_metaphlan_tables
 
 from metapi.uploader import gen_samples_info
 from metapi.uploader import gen_info
